/**
 * 断言
 *  - isString() - 字符类型
 *  - isNumber() - 数字类型
 *  - isBoolean() - 布尔类型
 *  - isUndefined() - undefined
 *  - isNull() - null
 *  - isFunction() - 函数类型
 *  - isObject() - 对象类型
 *  - isArray() - 数组类型
 *
 *  - isEventName() - 是否为事件名称 例如: 'onClick'
 *
 *  - isType() - 是否为某中类型 例如: isType('xx', 'string')
 *  - type() - 获取数据类型 例如: type('xxx') // string
 *
 * @example
 * ``` ts
 *  isString('xx')
 *  // => true
 * ```
 * @packageDocumentation
 * @module vx-tools/assert
 */
/**
 * 获取对象类型字符
 * @param data
 * @returns 类型字符
 */
export declare function type(data: unknown): string;
/**
 * 类型校验
 * @param data
 * @param typeStr
 */
export declare function isType(data: unknown, typeStr: string): boolean;
export declare const isString: (data: any) => data is string;
export declare const isNumber: (data: any) => data is number;
export declare const isBoolean: (data: any) => data is boolean;
export declare const isUndefined: (data: any) => data is undefined;
export declare const isNull: (data: any) => data is null;
export declare const isArray: (data: any) => data is any[];
export declare const isFunction: <T extends (...args: any[]) => any>(data: any) => data is T;
export declare const isObject: (data: any) => data is {
    [s: string]: any;
};
export declare const isEventName: (data: any) => data is string;
export declare const isSlotName: (data: any) => data is string;
