/**
 * 延时器
 * @packageDocumentation
 * @module vx-tools/Clock
 */
/**
 * 计时器
 * @summary
 * 记录一段或多段时间间隔
 *
 * @example
 * ```ts
 *  const c = new Clock // or Clock.create()
 *
 *  c.tick()
 *  setTimeout(() => {
 *    c.tick()
 *  }, 1000)
 *
 *  setTimeout(() => {
 *   console.log('time:', c.nextTick())
 *  }, 2000)
 *
 * ```
 */
export declare class Clock {
    static END: string;
    static create(): Clock;
    private _times;
    private _currentTick;
    _getTimes(): number[];
    /**
     * 打点记录
     */
    tick(): void;
    /**
     * 清空记录
     */
    clean(): void;
    /**
     * 记录条数
     * @returns number
     */
    len(): number;
    /**
     * 获取记录间隔
     * @param start
     * @param end
     * @returns
     */
    getTick(start: number, end: number): number;
    /**
     * 最后一条间隔
     * @returns number
     */
    lastTick(): number;
    /**
     * 第一条间隔
     * @returns number
     */
    firstTick(): number;
    /**
     * 每条间隔迭代器
     * @returns number
     */
    nextTick(): string | number;
    /**
     * 重置迭代器指针
     */
    resetTick(): void;
    /**
     * 当前迭代器指针位置
     */
    currentTick(): number;
}
